---
name: Dataset propose
about: Denote or add a dataset to DHG
title: Dataset
labels: Dataset
assignees: ''

---

**Where is the dataset from? Please describe.**
A clear and concise description of the source. Ex. collected in "Hypergraph Neural Networks" paper. collected in "SHREC22: Open-Set 3D Object Retrieval" challenge. etc.

**Describe the dataset**
A clear and concise description of the dataset. Ex. dataset name, a brief description, some statistic information, number of vertices, number of edges, number of classes, etc.

**Download link**
Where to access the dataset. Ex. a cloud drive link or any other website.

**Additional context**
Add any other context or dataset request here.
